[PATCH v5 3/3] drm/bridge: ite-it66121: Select HDMI or DVI mode based on sink type

From: Javier Martinez Canillas

Date: Sat May 23 2026 - 06:43:05 EST


The driver unconditionally sets the transmission mode to HDMI, which
leads to display output not working with DVI monitors. Check the
connector's display information sink type to identify the correct mode
to configure the bridge.

Signed-off-by: Javier Martinez Canillas <javierm@xxxxxxxxxx>
---
drivers/gpu/drm/bridge/ite-it66121.c | 7 +++++--
1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/bridge/ite-it66121.c b/drivers/gpu/drm/bridge/ite-it66121.c
index 9725e5db5db3..a469e8d9d2d8 100644
--- a/drivers/gpu/drm/bridge/ite-it66121.c
+++ b/drivers/gpu/drm/bridge/ite-it66121.c
@@ -199,6 +199,7 @@

#define IT66121_HDMI_MODE_REG 0xC0
#define IT66121_HDMI_MODE_HDMI BIT(0)
+#define IT66121_HDMI_MODE_DVI 0

#define IT66121_SYS_STATUS_REG 0x0E
#define IT66121_SYS_STATUS_ACTIVE_IRQ BIT(7)
@@ -692,8 +693,10 @@ static void it66121_set_mode(struct it66121_ctx *ctx,

mutex_lock(&ctx->lock);

- /* Set TX mode to HDMI */
- if (regmap_write(ctx->regmap, IT66121_HDMI_MODE_REG, IT66121_HDMI_MODE_HDMI))
+ /* Set TX mode to HDMI or DVI */
+ if (regmap_write(ctx->regmap, IT66121_HDMI_MODE_REG,
+ connector->display_info.is_hdmi ?
+ IT66121_HDMI_MODE_HDMI : IT66121_HDMI_MODE_DVI))
goto unlock;

if ((ctx->id == ID_IT66121 || ctx->id == ID_IT66122) &&

--
2.54.0